<?php
/*
Plugin Name: Get user info
Plugin URI: http://wordpress.org/extend/plugins/get-user-info/
Description: Choose to display any of the following for any user: User name, first and last name, avatar, description or website. A title can be added along with a css class to allow styling if needed. Is available as a widget or shortcode. Ex. [userinfo user="User Name" class="CssClass" title="My Title" username="true" name="true" avatar="true" description="true" website="true"].
Version: 1.2
Author: Jeff Freeman
Author URI: http://graphicalforce.com
*/

/**
 * Adds Featured_User widget.
 */
class Featured_Widget extends WP_Widget {

	/**
	 * Register widget with WordPress.
	 */
	public function __construct() {
		parent::__construct(
	 		'featured_widget', // Base ID
			'Get User Info', // Name
			array( 'description' => __( 'Display any of the following: user name, first and last name, description, avatar, and website of any user. Just enter the username.', 'text_domain' ), ) // Args
		);
	}

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {
		extract( $args );
		$title = apply_filters( 'widget_title', $instance['title'] );
		$cssClass = apply_filters('widget_title', empty($instance['cssClass']) ? '' : $instance['cssClass'], $instance);
		$user = apply_filters( 'widget_title', $instance['userName'] );
		$userNameDisplay = apply_filters( 'widget_title', $instance['userNameDisplay'] );
		$firstLast = apply_filters( 'widget_title', $instance['firstLast'] );
		$avatar = apply_filters( 'widget_title', $instance['avatar'] );
		$description = apply_filters( 'widget_title', $instance['description'] );
		$website = apply_filters( 'widget_title', $instance['website'] );
		if ( $cssClass ) {
            if( strpos($before_widget, 'class') === false ) {
                $before_widget = str_replace('>', 'class="'. $cssClass . '"', $before_widget);
            } else {
                $before_widget = str_replace('class="', 'class="'. $cssClass . ' ', $before_widget);
            }
        }
				
		$user = get_user_by('login', $user);
		$user_email = $user->user_email;
		if ( $userNameDisplay ) {
			$user_name = $user->user_login;
		}
		if ( $firstLast ) {
			$user_last = $user->last_name;
			$user_first = $user->first_name;
		}
		if ( $avatar ) {
			$user_avatar = get_avatar($user_email);
		}
		if ( $description ) {
			$user_description = $user->description;
		}
		if ( $website ) {
			$user_website = $user->user_url;
			$user_url = $user_website;
			$user_website = preg_replace('#^https?://#', '', $user_website);
			$user_website = preg_replace('#^www.#', '', $user_website);
        }
		
		echo $before_widget;
		if ( ! empty( $userName ) )
			echo $before_title . $userName . $after_title;
			echo "<h3 class=\"widget-title\">{$title}</h3>";
			echo "<h4>{$user_name}</h4>";
		    echo "<h4>{$user_first} {$user_last}</h4>";
			echo "{$user_avatar}";
			echo "<p>{$user_description}</p>";
			echo "<a href=\"{$user_url}\" target=\"_blank\">{$user_website}</a></p>";
		echo $after_widget;
	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['userName'] = strip_tags( $new_instance['userName'] );
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['cssClass'] = strip_tags($new_instance['cssClass']);
		$instance['userNameDisplay'] = ($new_instance['userNameDisplay']);
		$instance['firstLast'] = ($new_instance['firstLast']);
		$instance['avatar'] = ($new_instance['avatar']);
		$instance['description'] = ($new_instance['description']);
		$instance['website'] = ($new_instance['website']);

		return $instance;
	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {
		if ( isset( $instance[ 'userName' ] ) ) {
			$userName = $instance[ 'userName' ];
		}
		else {
			$userName = __( 'New Name', 'text_domain' );
		}
		if ( isset( $instance[ 'title' ] ) ) {
			$title = $instance['title'];
		}
		if ( isset( $instance[ 'cssClass' ] ) ) {
			$cssClass = strip_tags($instance['cssClass']);
		}
		if ( isset( $instance[ 'userNameDisplay' ] )) {
			$userNameDisplay = $instance['userNameDisplay'];
		}
		if ( isset( $instance[ 'firstLast' ] ) ) {
			$firstLast = $instance['firstLast'];
		}
		if ( isset( $instance[ 'avatar' ] ) ) {
			$avatar = $instance['avatar'];
		}
		if ( isset( $instance[ 'description' ] ) ) {
			$description = $instance['description'];
		}
		if ( isset( $instance[ 'website' ] ) ) {
			$website = $instance['website'];
		}
		
		?>
		<p>
		<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:' ); ?></label> 
		<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		<p>
		<label for="<?php echo $this->get_field_id('cssClass'); ?>"><?php _e('CSS Class:'); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('cssClass'); ?>" name="<?php echo $this->get_field_name('cssClass'); ?>" type="text" value="<?php echo esc_attr($cssClass); ?>" />
		</p>
		<p>
		<label for="<?php echo $this->get_field_id( 'userName' ); ?>"><?php _e( 'User Name' ); ?></label> 
		<input class="widefat" id="<?php echo $this->get_field_id( 'userName' ); ?>" name="<?php echo $this->get_field_name( 'userName' ); ?>" type="text" value="<?php echo esc_attr( $userName ); ?>" />
		</p>
		<p><strong>Check to display the following:</strong></p>
		<div class="wrap">
			<table class="form-table">
				<tr valign="top">				
					<th scope="row">
						<label for="<?php echo $this->get_field_id('userNameDisplay'); ?>"><?php _e('User name: '); ?></label>
					</th>
					<td>
						<input id="<?php echo $this->get_field_id( 'userNameDisplay' ); ?>" name="<?php echo $this->get_field_name( 'userNameDisplay' ); ?>" type="checkbox" <?php checked($userNameDisplay, 'on' ); ?> />
					</td>
				</tr>
				<tr valign="top">				
					<th scope="row">
						<label for="<?php echo $this->get_field_id('firstLast'); ?>"><?php _e('User first and last name: '); ?></label>
					</th>
					<td>
						<input id="<?php echo $this->get_field_id( 'firstLast' ); ?>" name="<?php echo $this->get_field_name( 'firstLast' ); ?>" type="checkbox" <?php checked($firstLast, 'on' ); ?> />
					</td>
				</tr>
			<tr valign="top">				
					<th scope="row">
						<label for="<?php echo $this->get_field_id('avatar'); ?>"><?php _e('User avatar: '); ?></label>
					</th>
					<td>
						<input id="<?php echo $this->get_field_id( 'avatar' ); ?>" name="<?php echo $this->get_field_name( 'avatar' ); ?>" type="checkbox" <?php checked($avatar, 'on' ); ?> />
					</td>
				</tr>
				<tr valign="top">				
					<th scope="row">
						<label for="<?php echo $this->get_field_id('description'); ?>"><?php _e('User description: '); ?></label>
					</th>
					<td>
						<input id="<?php echo $this->get_field_id( 'description' ); ?>" name="<?php echo $this->get_field_name( 'description' ); ?>" type="checkbox" <?php checked($description, 'on' ); ?> />
					</td>
				</tr>
				<tr valign="top">				
					<th scope="row">
						<label for="<?php echo $this->get_field_id('website'); ?>"><?php _e('User website: '); ?></label>
					</th>
					<td>
						<input id="<?php echo $this->get_field_id( 'website' ); ?>" name="<?php echo $this->get_field_name( 'website' ); ?>" type="checkbox" <?php checked($website, 'on' ); ?> />
					</td>
				</tr>
			</table>
		</div>
		<?php 
	}

} // class Featured_User

// register Get User Info widget
add_action( 'widgets_init', create_function( '', 'register_widget( "featured_widget" );' ) );

/**
 * Adds Featured_User shortcode.
 */
 function getUserInfo( $atts ) {
	 extract( shortcode_atts( array(
			'user' => 'something',
			'class' => '',
			'title' => '',
			'username' => 'false',
			'name' => 'false',
			'avatar' => 'false',
			'description' => 'false',
			'website' => 'false',
		), $atts ) );
		
		$cssClass = ($class);
		$userTitle = ($title);
		$userNameDisplay = ($username);
		$firstLast = ($name);
		$avatar = ($avatar);
		$description = ($description);
		$website = ($website);
		$user = get_userdatabylogin($user);
		$user_email = $user->user_email;
		if ( $userNameDisplay === 'true' ) {
			$user_name = $user->user_login;
		}
		if ( $firstLast === 'true' ) {
			$user_last = $user->last_name;
			$user_first = $user->first_name;			
		}
		if ( $avatar === 'true' ) {
			$user_avatar = get_avatar($user_email);
		}
		if ( $description === 'true' ) {
			$user_description = $user->description;
		}
		if ( $website === 'true' ) {
			$user_website = $user->user_url;
			$user_url = $user_website;
			$user_website = preg_replace('#^https?://#', '', $user_website);
			$user_website = preg_replace('#^www.#', '', $user_website);
        }
		
		$return_string = '<div class="' . $cssClass . '">';
		$return_string .= '<h3>' . $userTitle . '</h3><br/>';
		$return_string .= $user_name . '<br/>';
		$return_string .= $user_first . $user_last . '<br/>';
		$return_string .= $user_avatar . '<br/>';
		$return_string .= $user_description .'<br/>';
		$return_string .= $user_website;
		$return_string .= '</div>';
		
		return $return_string;
}

// register shortcode
add_shortcode('userinfo', 'getUserInfo');

?>